Crate holochain_client
source ·Structs
- The request payload that should be sent in a [
holochain_websocket::WireMessage::Authenticate] - Response payload for AdminResponse::AppAuthenticationTokenIssued.
- Info about an installed app, returned as part of
AppResponse::AppInfo - Request payload for AdminRequest::IssueAppAuthenticationToken.
- The data provided over an app interface in order to make a zome call
Enums
- Represents the available conductor functions to call over an admin interface.
- Represents the possible responses to an
AdminRequestand follows a general convention ofnoun_verbas opposed to theverb_nounofAdminRequest. - Represents the available conductor functions to call over an app interface and will result in a corresponding
AppResponsemessage being sent back over the interface connection. - Represents the possible responses to an
AppRequest. - Filter for
AdminRequest::ListApps.
Traits
Type Aliases
- An Agent public signing key. Not really a hash, more of an “identity hash”.
- A token issued by the conductor that can be used to authenticate a connection to an app interface.
- The unique identifier for an installed app in this conductor