Struct holochain_client::InstallAppPayload
source · pub struct InstallAppPayload {
pub source: AppBundleSource,
pub agent_key: Option<HoloHash<Agent>>,
pub installed_app_id: Option<String>,
pub membrane_proofs: Option<HashMap<String, Arc<SerializedBytes>>>,
pub existing_cells: HashMap<String, CellId>,
pub network_seed: Option<String>,
pub ignore_genesis_failure: bool,
}Expand description
An AppBundle along with an AgentPubKey and optional InstalledAppId
Fields
source: AppBundleSourceThe unique identifier for an installed app in this conductor.
agent_key: Option<HoloHash<Agent>>The agent to use when creating Cells for this App. If None, a new agent key will be generated.
If a DPKI service is initialized at installation time, this field will be ignored and a properly derived key will be used instead.
installed_app_id: Option<String>The unique identifier for an installed app in this conductor. If not specified, it will be derived from the app name in the bundle manifest.
membrane_proofs: Option<HashMap<String, Arc<SerializedBytes>>>Include proof-of-membrane-membership data for cells that require it, keyed by the RoleName specified in the app bundle manifest.
When the app being installed has the allow_deferred_memproofs manifest flag set,
passing None for this field will allow the app to enter the “deferred membrane proofs”
state, so that memproofs can be provided later via [AppRequest::ProvideMemproofs].
If Some is used here, whatever memproofs are provided will be used, and the app will
be installed as normal.
existing_cells: HashMap<String, CellId>For each role in the app manifest which has UseExisting cell provisioning, a CellId of a currently installed cell must be specified in this map.
network_seed: Option<String>Optional: overwrites all network seeds for all DNAs of Cells created by this app. The app can still use existing Cells, i.e. this does not require that all Cells have DNAs with the same overridden DNA.
ignore_genesis_failure: boolOptional: If app installation fails due to genesis failure, normally the app will be
immediately uninstalled. When this flag is set, the app is left installed with empty cells intact.
This can be useful for using graft_records_onto_source_chain, or for diagnostics.